# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/w0rm/projects/python/pyqtrailer/pyqtrailer/qtcustom/settings.ui'
#
# Created: Fri Oct 22 17:48:37 2010
#      by: PyQt4 UI code generator 4.7.7
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_SettingsDialog(object):
    def setupUi(self, SettingsDialog):
        SettingsDialog.setObjectName(_fromUtf8("SettingsDialog"))
        SettingsDialog.resize(467, 404)
        self.gridLayout = QtGui.QGridLayout(SettingsDialog)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.groupBox_2 = QtGui.QGroupBox(SettingsDialog)
        self.groupBox_2.setObjectName(_fromUtf8("groupBox_2"))
        self.horizontalLayout = QtGui.QHBoxLayout(self.groupBox_2)
        self.horizontalLayout.setObjectName(_fromUtf8("horizontalLayout"))
        self.downloadPath = QtGui.QLineEdit(self.groupBox_2)
        self.downloadPath.setText(_fromUtf8(""))
        self.downloadPath.setObjectName(_fromUtf8("downloadPath"))
        self.horizontalLayout.addWidget(self.downloadPath)
        self.browseButton = QtGui.QPushButton(self.groupBox_2)
        self.browseButton.setObjectName(_fromUtf8("browseButton"))
        self.horizontalLayout.addWidget(self.browseButton)
        self.gridLayout.addWidget(self.groupBox_2, 0, 0, 1, 2)
        self.groupBox = QtGui.QGroupBox(SettingsDialog)
        self.groupBox.setMaximumSize(QtCore.QSize(16777215, 150))
        self.groupBox.setObjectName(_fromUtf8("groupBox"))
        self.gridLayout_2 = QtGui.QGridLayout(self.groupBox)
        self.gridLayout_2.setObjectName(_fromUtf8("gridLayout_2"))
        self.filterList = QtGui.QListWidget(self.groupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.filterList.sizePolicy().hasHeightForWidth())
        self.filterList.setSizePolicy(sizePolicy)
        self.filterList.setMinimumSize(QtCore.QSize(80, 110))
        self.filterList.setMaximumSize(QtCore.QSize(80, 110))
        self.filterList.setObjectName(_fromUtf8("filterList"))
        QtGui.QListWidgetItem(self.filterList)
        QtGui.QListWidgetItem(self.filterList)
        QtGui.QListWidgetItem(self.filterList)
        QtGui.QListWidgetItem(self.filterList)
        QtGui.QListWidgetItem(self.filterList)
        QtGui.QListWidgetItem(self.filterList)
        self.gridLayout_2.addWidget(self.filterList, 0, 0, 3, 1)
        self.qualityUp = QtGui.QToolButton(self.groupBox)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(_fromUtf8("../../../../../../../usr/share/icons/oxygen/32x32/actions/go-up.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.qualityUp.setIcon(icon)
        self.qualityUp.setObjectName(_fromUtf8("qualityUp"))
        self.gridLayout_2.addWidget(self.qualityUp, 0, 1, 1, 1)
        self.qualityDown = QtGui.QToolButton(self.groupBox)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(_fromUtf8("../../../../../../../usr/share/icons/oxygen/32x32/actions/go-down.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.qualityDown.setIcon(icon1)
        self.qualityDown.setObjectName(_fromUtf8("qualityDown"))
        self.gridLayout_2.addWidget(self.qualityDown, 1, 1, 1, 1)
        spacerItem = QtGui.QSpacerItem(20, 45, QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        self.gridLayout_2.addItem(spacerItem, 2, 1, 1, 1)
        self.gridLayout.addWidget(self.groupBox, 1, 0, 1, 1)
        self.groupBox_3 = QtGui.QGroupBox(SettingsDialog)
        self.groupBox_3.setMaximumSize(QtCore.QSize(16777215, 150))
        self.groupBox_3.setObjectName(_fromUtf8("groupBox_3"))
        self.verticalLayout = QtGui.QVBoxLayout(self.groupBox_3)
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.horizontalLayout_3 = QtGui.QHBoxLayout()
        self.horizontalLayout_3.setObjectName(_fromUtf8("horizontalLayout_3"))
        self.label = QtGui.QLabel(self.groupBox_3)
        self.label.setObjectName(_fromUtf8("label"))
        self.horizontalLayout_3.addWidget(self.label)
        spacerItem1 = QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem1)
        self.spinReadAhead = QtGui.QSpinBox(self.groupBox_3)
        self.spinReadAhead.setMaximumSize(QtCore.QSize(16777215, 30))
        self.spinReadAhead.setMinimum(1)
        self.spinReadAhead.setMaximum(10)
        self.spinReadAhead.setProperty(_fromUtf8("value"), 4)
        self.spinReadAhead.setObjectName(_fromUtf8("spinReadAhead"))
        self.horizontalLayout_3.addWidget(self.spinReadAhead)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.horizontalLayout_2 = QtGui.QHBoxLayout()
        self.horizontalLayout_2.setObjectName(_fromUtf8("horizontalLayout_2"))
        self.label_2 = QtGui.QLabel(self.groupBox_3)
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.horizontalLayout_2.addWidget(self.label_2)
        spacerItem2 = QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem2)
        self.spinParallelDownload = QtGui.QSpinBox(self.groupBox_3)
        self.spinParallelDownload.setMaximumSize(QtCore.QSize(16777215, 30))
        self.spinParallelDownload.setMinimum(1)
        self.spinParallelDownload.setMaximum(5)
        self.spinParallelDownload.setProperty(_fromUtf8("value"), 2)
        self.spinParallelDownload.setObjectName(_fromUtf8("spinParallelDownload"))
        self.horizontalLayout_2.addWidget(self.spinParallelDownload)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.gridLayout.addWidget(self.groupBox_3, 1, 1, 1, 1)
        self.groupBox_4 = QtGui.QGroupBox(SettingsDialog)
        self.groupBox_4.setObjectName(_fromUtf8("groupBox_4"))
        self.verticalLayout_2 = QtGui.QVBoxLayout(self.groupBox_4)
        self.verticalLayout_2.setObjectName(_fromUtf8("verticalLayout_2"))
        self.horizontalLayout_4 = QtGui.QHBoxLayout()
        self.horizontalLayout_4.setObjectName(_fromUtf8("horizontalLayout_4"))
        self.label_3 = QtGui.QLabel(self.groupBox_4)
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.horizontalLayout_4.addWidget(self.label_3)
        self.playerCommand = QtGui.QLineEdit(self.groupBox_4)
        self.playerCommand.setObjectName(_fromUtf8("playerCommand"))
        self.horizontalLayout_4.addWidget(self.playerCommand)
        self.verticalLayout_2.addLayout(self.horizontalLayout_4)
        self.label_4 = QtGui.QLabel(self.groupBox_4)
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.verticalLayout_2.addWidget(self.label_4)
        self.label_5 = QtGui.QLabel(self.groupBox_4)
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.verticalLayout_2.addWidget(self.label_5)
        self.gridLayout.addWidget(self.groupBox_4, 2, 0, 1, 2)
        self.buttonBox = QtGui.QDialogButtonBox(SettingsDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.gridLayout.addWidget(self.buttonBox, 3, 1, 1, 1)

        self.retranslateUi(SettingsDialog)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), SettingsDialog.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), SettingsDialog.reject)
        QtCore.QMetaObject.connectSlotsByName(SettingsDialog)

    def retranslateUi(self, SettingsDialog):
        SettingsDialog.setWindowTitle(QtGui.QApplication.translate("SettingsDialog", "Dialog", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox_2.setTitle(QtGui.QApplication.translate("SettingsDialog", "&Download path", None, QtGui.QApplication.UnicodeUTF8))
        self.browseButton.setText(QtGui.QApplication.translate("SettingsDialog", "Browse", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setTitle(QtGui.QApplication.translate("SettingsDialog", "&Quality priority", None, QtGui.QApplication.UnicodeUTF8))
        __sortingEnabled = self.filterList.isSortingEnabled()
        self.filterList.setSortingEnabled(False)
        self.filterList.item(0).setText(QtGui.QApplication.translate("SettingsDialog", "480p", None, QtGui.QApplication.UnicodeUTF8))
        self.filterList.item(1).setText(QtGui.QApplication.translate("SettingsDialog", "720p", None, QtGui.QApplication.UnicodeUTF8))
        self.filterList.item(2).setText(QtGui.QApplication.translate("SettingsDialog", "1080p", None, QtGui.QApplication.UnicodeUTF8))
        self.filterList.item(3).setText(QtGui.QApplication.translate("SettingsDialog", "640x360", None, QtGui.QApplication.UnicodeUTF8))
        self.filterList.item(4).setText(QtGui.QApplication.translate("SettingsDialog", "320x180", None, QtGui.QApplication.UnicodeUTF8))
        self.filterList.item(5).setText(QtGui.QApplication.translate("SettingsDialog", "480x204", None, QtGui.QApplication.UnicodeUTF8))
        self.filterList.setSortingEnabled(__sortingEnabled)
        self.qualityUp.setText(QtGui.QApplication.translate("SettingsDialog", "...", None, QtGui.QApplication.UnicodeUTF8))
        self.qualityDown.setText(QtGui.QApplication.translate("SettingsDialog", "...", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox_3.setTitle(QtGui.QApplication.translate("SettingsDialog", "&Performance", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("SettingsDialog", "Read ahead processes", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("SettingsDialog", "Maxiumum parallel downloads", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox_4.setTitle(QtGui.QApplication.translate("SettingsDialog", "Viewing", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("SettingsDialog", "Command: ", None, QtGui.QApplication.UnicodeUTF8))
        self.playerCommand.setText(QtGui.QApplication.translate("SettingsDialog", "mplayer -user-agent %a %u", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("SettingsDialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Bitstream Vera Serif\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:11pt; font-weight:600;\">%u</span> will be replaced with trailer URL</p></body></html>", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("SettingsDialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Bitstream Vera Serif\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:11pt; font-weight:600;\">%a</span> will be replaced with user-agent string</p></body></html>", None, QtGui.QApplication.UnicodeUTF8))

